// mozileDetection.js

/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code.
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *		Karl Guertin <grayrest@grayrest.com>
 *		James A. Overton <james@overton.ca>
 *		Christian Stocker (Bitflux)
 *		Paul Everitt
 *		David Palm
 *
 * ***** END LICENSE BLOCK ***** */

/*******

Mozile Detection Javascript
Mozile version 0.61

Created by James A. Overton
Created on 2004-03-24

Last revised by James A. Overton
Last revised on 2004-04-09

HISTORY:
	Some code in this file was first found in mozilehtmltb.js, while the 
majority was cut out of mozileTB.js and separated into different files.


DESCRIPTION:
	The code here is responsible for detecting when Mozile should be active.
It gets called a lot, so mozileDetect() has to be very fast.

*********/


//window.addEventListener("close", mozileUnload, true);
//window.addEventListener("unload", mozileUnload, true);

function mozileUnload(event) {
	confirm("Do you want to leave the page?");
			event.stopPropagation();
		event.returnValue = false;
  		event.preventDefault();
  		return false;
}



function mozileGetCurrentTarget() {
	return mozileTarget;
}

function mozileIsContentEditable(nodeToCheck) {
		while(nodeToCheck)
		{
			// find a non element node - return: probably DOCUMENT_NODE reached!
			if(nodeToCheck.nodeType != Node.ELEMENT_NODE)
				return 0;
			// if has a content editable attribute then sync it with mozusermodify
			if(nodeToCheck.getAttribute("contentEditable"))
			{
				if(nodeToCheck.getAttribute("contentEditable") == "true")
					return 1;
				return 0;
			}
			nodeToCheck = nodeToCheck.parentNode;
		}
}



// Mozile Detect
// Check for the mozileChromeLoaded flag.
// Check to see if the user has selected an editable area.
// If so, set the global mozileTarget and mozileSelection variables.
// If not, return 0, and don't do anything else.

function mozileDetect() {

	try{
	
			// get the selection of the focussed window
		var mozileCheckTarget = document.commandDispatcher.focusedWindow;
		var mozileCheckSelection = mozileCheckTarget.getSelection();
		
			// if we're in the browser, as opposed to a document, Mozile can't edit
		if(mozileCheckTarget.document.documentElement==document.documentElement) {
			return 0;
		}
	
	
			// if there's no node, Mozile won't be able to edit
		try{ 
			mozileCheckSelection.anchorNode.parentNode;
		} catch(e) {
			//alert("Fixed?");
			mozileClearButtons();
			return 0;
		}
	
/*			// don't edit these nodes!			
		var ignoreList = new Array("input","textarea");
		for(var i=0; i<ignoreList.length; i++) {
			if(mozileCheckSelection.anchorNode.tagName.toLowerCase()==ignoreList[i]) {
				return 0;
			}
		}
*/

			// undo/redo can change the selection to the documentElement, so ignore a sudden change
		if(mozileCheckTarget.document.documentElement == mozileCheckSelection.anchorNode) {
			return 1;
		}
		
			// is it the same (editable) node?
		try{
			if(mozileLastContextNode == mozileGetContext(mozileCheckSelection)) {
				return 1;
			}
		} catch(e) { }
			

			// check if the selection is editable
		var CSSenabled = mozileCheckTarget.document.defaultView.getComputedStyle(mozileCheckSelection.anchorNode.parentNode, null).MozUserModify;
		
			// check CSS first, it's fast
		if(CSSenabled!="read-write") {
		
				// only check if necessary, since it's slow
			var CEenabled = mozileIsContentEditable(mozileCheckSelection.anchorNode.parentNode);
			
			if(CEenabled!=1) {
				mozileClearCommandMenu();
				mozileClearButtons();
				mozileLastContextNode="";
				return 0;
			}
		}
	
		var mozileInjected=0;
			// if mozileChromeLoaded is false, inject the code
		if(!mozileCheckTarget.mozileChromeLoaded
				|| mozileCheckTarget.mozileChromeLoaded != "true") {
			mozileInject(mozileCheckTarget);
			mozileInjected=1;
			//alert("MozileInjected");
		}
				
			// now we can set mozileTarget
		mozileTarget = document.commandDispatcher.focusedWindow;
		
			// now we can set mozileSelection
		mozileSelection = mozileTarget.getSelection();
		
		if(mozileInjected) {
				mozileUpdateCommandMenu();
				mozileUpdateButtons();
				mozileUpdateUndoButtons();
		}
		else {
				// update the buttons only if the context node has changed
			try{
				if(mozileLastContextNode != mozileGetContext(mozileSelection).anchorNode) {
					//alert("Updating Buttons");
					mozileUpdateCommandMenu();
					mozileUpdateButtons();
				}
			} catch(e) { }
		}
		
			// these are from the current ediatble node.
		mozileLastContextNode = mozileGetContext(mozileSelection);
		
			// done
		return 1;
	
	}
	catch(e) { 
		alert("Detect Died: "+e);
		return 0; 
	}

/**  Sorry for the cruft...

			var contextTag = mozileGetContext().tagName.toLowerCase();
			var tagIndex = findByName(contextTag, mesTags);
			//alert("Context: "+contextTag+"\nIndex: "+tagIndex);
			//alert("Commands: "+mesTags[tagIndex][3]);
			if(tagIndex<0) {
				alert("Context undefined!"); break; 
			}
			//mozileMakeMenu(mesTags[tagIndex][3]);
			
			if(!mozileToolbar || mozileToolbar=="") {
				mozileToolbar = document.getElementById("mozile-toolbar");
			}
			
			mozileMakeCommandMenu(mesTags[tagIndex][3]);
			mozileClearToolbar();
			mozileMakeButtons(mesTags[tagIndex][3]);
			
			//alert(printXML(document.getElementById("mozile-toolbar")));



		// if the currently focussed window does not have the mozileChromeLoaded flag set, then Mozile shouldn't do anything.
	if(!document.commandDispatcher.focusedWindow.mozileChromeLoaded
			|| document.commandDispatcher.focusedWindow.mozileChromeLoaded != "true") {
		return 0;
	}

	mozileTarget = document.commandDispatcher.focusedWindow;

		// undo/redo can change the selection to the documentElement, so ignore a sudden change
	if(mozileTarget.document.documentElement == mozileSelection.anchorNode) {
		return 1;
	}

	mozileSelection = mozileTarget.getSelection();

if( mozileTarget.document.defaultView.getComputedStyle(mozileSelection.anchorNode.parentNode, null).MozUserModify ) {
	alert("CSS enabled");
	editable=1;
}
if(mozileSelection.anchorNode.parentNode.isContentEditable) {
	alert("contentEditable=true");
	editable=1;
}
if(!editable) {
	alert("Not editable");
}


		// test the parent node of the node containing the selection to see if it is editable.
	if(!mozileSelection.anchorNode.parentNode.userModifiable) {
		return 0;
	}

	return 1;
	
	**/

} // end mozileDetect()


